@@ -18,7 +18,6 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 """
-import logging
 import os
 import re
 from typing import (
@@ -27,39 +26,10 @@ from typing import (
 
 from wechaty_puppet import (    # type: ignore
     FileBox,
+    get_logger
 )
 
 
-def get_logger(name: str) -> logging.Logger:
-    """
-    configured Loggers
-    """
-    WECHATY_LOG_KEY = 'WECHATY_LOG'
-
-    if WECHATY_LOG_KEY in os.environ:
-        WECHATY_LOG = os.environ[WECHATY_LOG_KEY].upper()
-    else:
-        WECHATY_LOG = 'INFO'
-
-    LOGGER_LEVELS = [
-        'CRITICAL',
-        'ERROR',
-        'WARNING',
-        'INFO',
-        'DEBUG',
-    ]
-
-    if WECHATY_LOG in LOGGER_LEVELS:
-        level = getattr(logging, WECHATY_LOG, logging.INFO)
-    else:
-        level = logging.INFO
-
-    _log = logging.getLogger(name)
-    _log.setLevel(level)
-
-    return _log
-
-
 log = get_logger('Config')
 
 # log.debug('test logging debug')
