@@ -23,33 +23,26 @@ from typing import (
     Optional,
     Union,
     List,
-    TYPE_CHECKING,
 )
 
 from datetime import datetime
 from wechaty_puppet import (    # type: ignore
+    FileBox,
     MessagePayload,
     MessageQueryFilter,
     MessageType,
+    get_logger
 )
 
 from ..accessory import Accessory
-from ..config import (
-    get_logger,
-)
 from .mini_program import MiniProgram
 # TODO -> remove Sayable interface temporary
 # from ..types import Sayable
 
 from .contact import Contact
-
-if TYPE_CHECKING:
-    from .url_link import UrlLink
-    from .image import Image
-    from .room import Room
-    from wechaty_puppet import (
-        FileBox
-    )
+from .url_link import UrlLink
+from .image import Image
+from .room import Room
 
 log = get_logger('Message')
 
